python-oas
==========

.. image:: https://img.shields.io/pypi/v/oas.svg
   :alt: PyPI
   :target: https://pypi.org/project/oas

.. image:: https://img.shields.io/travis/grktsh/python-oas/master.svg
   :alt: Travis
   :target: https://travis-ci.org/grktsh/python-oas

.. image:: https://img.shields.io/codecov/c/github/grktsh/python-oas/master.svg
   :alt: Codecov
   :target: https://codecov.io/gh/grktsh/python-oas

Prerequisites
-------------

- Validated OpenAPI 3 document

  - python-oas does not validate OpenAPI 3 document itself at runtime.  It should be validated in advance.
